"""
Type annotations for ivs-realtime service type definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ivs_realtime/type_defs/)

Usage::

    ```python
    from types_aiobotocore_ivs_realtime.type_defs import AutoParticipantRecordingConfigurationOutputTypeDef

    data: AutoParticipantRecordingConfigurationOutputTypeDef = ...
    ```
"""

import sys
from datetime import datetime
from typing import Dict, List, Mapping, Sequence, Union

from .literals import (
    CompositionStateType,
    DestinationStateType,
    EventErrorCodeType,
    EventNameType,
    ParticipantRecordingFilterByRecordingStateType,
    ParticipantRecordingMediaTypeType,
    ParticipantRecordingStateType,
    ParticipantStateType,
    ParticipantTokenCapabilityType,
    PipBehaviorType,
    PipPositionType,
    VideoAspectRatioType,
    VideoFillModeType,
)

if sys.version_info >= (3, 12):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 12):
    from typing import NotRequired
else:
    from typing_extensions import NotRequired
if sys.version_info >= (3, 12):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict

__all__ = (
    "AutoParticipantRecordingConfigurationOutputTypeDef",
    "AutoParticipantRecordingConfigurationTypeDef",
    "ChannelDestinationConfigurationTypeDef",
    "DestinationSummaryTypeDef",
    "VideoTypeDef",
    "ResponseMetadataTypeDef",
    "CreateParticipantTokenRequestRequestTypeDef",
    "ParticipantTokenTypeDef",
    "ParticipantTokenConfigurationTypeDef",
    "S3StorageConfigurationTypeDef",
    "DeleteEncoderConfigurationRequestRequestTypeDef",
    "DeleteStageRequestRequestTypeDef",
    "DeleteStorageConfigurationRequestRequestTypeDef",
    "S3DetailTypeDef",
    "DisconnectParticipantRequestRequestTypeDef",
    "EncoderConfigurationSummaryTypeDef",
    "EventTypeDef",
    "GetCompositionRequestRequestTypeDef",
    "GetEncoderConfigurationRequestRequestTypeDef",
    "GetParticipantRequestRequestTypeDef",
    "ParticipantTypeDef",
    "GetStageRequestRequestTypeDef",
    "GetStageSessionRequestRequestTypeDef",
    "StageSessionTypeDef",
    "GetStorageConfigurationRequestRequestTypeDef",
    "GridConfigurationTypeDef",
    "PipConfigurationTypeDef",
    "ListCompositionsRequestRequestTypeDef",
    "ListEncoderConfigurationsRequestRequestTypeDef",
    "ListParticipantEventsRequestRequestTypeDef",
    "ListParticipantsRequestRequestTypeDef",
    "ParticipantSummaryTypeDef",
    "ListStageSessionsRequestRequestTypeDef",
    "StageSessionSummaryTypeDef",
    "ListStagesRequestRequestTypeDef",
    "StageSummaryTypeDef",
    "ListStorageConfigurationsRequestRequestTypeDef",
    "ListTagsForResourceRequestRequestTypeDef",
    "RecordingConfigurationTypeDef",
    "StopCompositionRequestRequestTypeDef",
    "TagResourceRequestRequestTypeDef",
    "UntagResourceRequestRequestTypeDef",
    "StageTypeDef",
    "AutoParticipantRecordingConfigurationUnionTypeDef",
    "UpdateStageRequestRequestTypeDef",
    "CompositionSummaryTypeDef",
    "CreateEncoderConfigurationRequestRequestTypeDef",
    "EncoderConfigurationTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "CreateParticipantTokenResponseTypeDef",
    "CreateStageRequestRequestTypeDef",
    "CreateStorageConfigurationRequestRequestTypeDef",
    "StorageConfigurationSummaryTypeDef",
    "StorageConfigurationTypeDef",
    "DestinationDetailTypeDef",
    "ListEncoderConfigurationsResponseTypeDef",
    "ListParticipantEventsResponseTypeDef",
    "GetParticipantResponseTypeDef",
    "GetStageSessionResponseTypeDef",
    "LayoutConfigurationTypeDef",
    "ListParticipantsResponseTypeDef",
    "ListStageSessionsResponseTypeDef",
    "ListStagesResponseTypeDef",
    "S3DestinationConfigurationOutputTypeDef",
    "S3DestinationConfigurationTypeDef",
    "CreateStageResponseTypeDef",
    "GetStageResponseTypeDef",
    "UpdateStageResponseTypeDef",
    "ListCompositionsResponseTypeDef",
    "CreateEncoderConfigurationResponseTypeDef",
    "GetEncoderConfigurationResponseTypeDef",
    "ListStorageConfigurationsResponseTypeDef",
    "CreateStorageConfigurationResponseTypeDef",
    "GetStorageConfigurationResponseTypeDef",
    "DestinationConfigurationOutputTypeDef",
    "DestinationConfigurationTypeDef",
    "DestinationTypeDef",
    "DestinationConfigurationUnionTypeDef",
    "CompositionTypeDef",
    "StartCompositionRequestRequestTypeDef",
    "GetCompositionResponseTypeDef",
    "StartCompositionResponseTypeDef",
)

AutoParticipantRecordingConfigurationOutputTypeDef = TypedDict(
    "AutoParticipantRecordingConfigurationOutputTypeDef",
    {
        "storageConfigurationArn": str,
        "mediaTypes": NotRequired[List[ParticipantRecordingMediaTypeType]],
    },
)
AutoParticipantRecordingConfigurationTypeDef = TypedDict(
    "AutoParticipantRecordingConfigurationTypeDef",
    {
        "storageConfigurationArn": str,
        "mediaTypes": NotRequired[Sequence[ParticipantRecordingMediaTypeType]],
    },
)
ChannelDestinationConfigurationTypeDef = TypedDict(
    "ChannelDestinationConfigurationTypeDef",
    {
        "channelArn": str,
        "encoderConfigurationArn": NotRequired[str],
    },
)
DestinationSummaryTypeDef = TypedDict(
    "DestinationSummaryTypeDef",
    {
        "id": str,
        "state": DestinationStateType,
        "startTime": NotRequired[datetime],
        "endTime": NotRequired[datetime],
    },
)
VideoTypeDef = TypedDict(
    "VideoTypeDef",
    {
        "width": NotRequired[int],
        "height": NotRequired[int],
        "framerate": NotRequired[float],
        "bitrate": NotRequired[int],
    },
)
ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
        "HostId": NotRequired[str],
    },
)
CreateParticipantTokenRequestRequestTypeDef = TypedDict(
    "CreateParticipantTokenRequestRequestTypeDef",
    {
        "stageArn": str,
        "duration": NotRequired[int],
        "userId": NotRequired[str],
        "attributes": NotRequired[Mapping[str, str]],
        "capabilities": NotRequired[Sequence[ParticipantTokenCapabilityType]],
    },
)
ParticipantTokenTypeDef = TypedDict(
    "ParticipantTokenTypeDef",
    {
        "participantId": NotRequired[str],
        "token": NotRequired[str],
        "userId": NotRequired[str],
        "attributes": NotRequired[Dict[str, str]],
        "duration": NotRequired[int],
        "capabilities": NotRequired[List[ParticipantTokenCapabilityType]],
        "expirationTime": NotRequired[datetime],
    },
)
ParticipantTokenConfigurationTypeDef = TypedDict(
    "ParticipantTokenConfigurationTypeDef",
    {
        "duration": NotRequired[int],
        "userId": NotRequired[str],
        "attributes": NotRequired[Mapping[str, str]],
        "capabilities": NotRequired[Sequence[ParticipantTokenCapabilityType]],
    },
)
S3StorageConfigurationTypeDef = TypedDict(
    "S3StorageConfigurationTypeDef",
    {
        "bucketName": str,
    },
)
DeleteEncoderConfigurationRequestRequestTypeDef = TypedDict(
    "DeleteEncoderConfigurationRequestRequestTypeDef",
    {
        "arn": str,
    },
)
DeleteStageRequestRequestTypeDef = TypedDict(
    "DeleteStageRequestRequestTypeDef",
    {
        "arn": str,
    },
)
DeleteStorageConfigurationRequestRequestTypeDef = TypedDict(
    "DeleteStorageConfigurationRequestRequestTypeDef",
    {
        "arn": str,
    },
)
S3DetailTypeDef = TypedDict(
    "S3DetailTypeDef",
    {
        "recordingPrefix": str,
    },
)
DisconnectParticipantRequestRequestTypeDef = TypedDict(
    "DisconnectParticipantRequestRequestTypeDef",
    {
        "stageArn": str,
        "participantId": str,
        "reason": NotRequired[str],
    },
)
EncoderConfigurationSummaryTypeDef = TypedDict(
    "EncoderConfigurationSummaryTypeDef",
    {
        "arn": str,
        "name": NotRequired[str],
        "tags": NotRequired[Dict[str, str]],
    },
)
EventTypeDef = TypedDict(
    "EventTypeDef",
    {
        "name": NotRequired[EventNameType],
        "participantId": NotRequired[str],
        "eventTime": NotRequired[datetime],
        "remoteParticipantId": NotRequired[str],
        "errorCode": NotRequired[EventErrorCodeType],
    },
)
GetCompositionRequestRequestTypeDef = TypedDict(
    "GetCompositionRequestRequestTypeDef",
    {
        "arn": str,
    },
)
GetEncoderConfigurationRequestRequestTypeDef = TypedDict(
    "GetEncoderConfigurationRequestRequestTypeDef",
    {
        "arn": str,
    },
)
GetParticipantRequestRequestTypeDef = TypedDict(
    "GetParticipantRequestRequestTypeDef",
    {
        "stageArn": str,
        "sessionId": str,
        "participantId": str,
    },
)
ParticipantTypeDef = TypedDict(
    "ParticipantTypeDef",
    {
        "participantId": NotRequired[str],
        "userId": NotRequired[str],
        "state": NotRequired[ParticipantStateType],
        "firstJoinTime": NotRequired[datetime],
        "attributes": NotRequired[Dict[str, str]],
        "published": NotRequired[bool],
        "ispName": NotRequired[str],
        "osName": NotRequired[str],
        "osVersion": NotRequired[str],
        "browserName": NotRequired[str],
        "browserVersion": NotRequired[str],
        "sdkVersion": NotRequired[str],
        "recordingS3BucketName": NotRequired[str],
        "recordingS3Prefix": NotRequired[str],
        "recordingState": NotRequired[ParticipantRecordingStateType],
    },
)
GetStageRequestRequestTypeDef = TypedDict(
    "GetStageRequestRequestTypeDef",
    {
        "arn": str,
    },
)
GetStageSessionRequestRequestTypeDef = TypedDict(
    "GetStageSessionRequestRequestTypeDef",
    {
        "stageArn": str,
        "sessionId": str,
    },
)
StageSessionTypeDef = TypedDict(
    "StageSessionTypeDef",
    {
        "sessionId": NotRequired[str],
        "startTime": NotRequired[datetime],
        "endTime": NotRequired[datetime],
    },
)
GetStorageConfigurationRequestRequestTypeDef = TypedDict(
    "GetStorageConfigurationRequestRequestTypeDef",
    {
        "arn": str,
    },
)
GridConfigurationTypeDef = TypedDict(
    "GridConfigurationTypeDef",
    {
        "featuredParticipantAttribute": NotRequired[str],
        "omitStoppedVideo": NotRequired[bool],
        "videoAspectRatio": NotRequired[VideoAspectRatioType],
        "videoFillMode": NotRequired[VideoFillModeType],
        "gridGap": NotRequired[int],
    },
)
PipConfigurationTypeDef = TypedDict(
    "PipConfigurationTypeDef",
    {
        "featuredParticipantAttribute": NotRequired[str],
        "omitStoppedVideo": NotRequired[bool],
        "videoFillMode": NotRequired[VideoFillModeType],
        "gridGap": NotRequired[int],
        "pipParticipantAttribute": NotRequired[str],
        "pipBehavior": NotRequired[PipBehaviorType],
        "pipOffset": NotRequired[int],
        "pipPosition": NotRequired[PipPositionType],
        "pipWidth": NotRequired[int],
        "pipHeight": NotRequired[int],
    },
)
ListCompositionsRequestRequestTypeDef = TypedDict(
    "ListCompositionsRequestRequestTypeDef",
    {
        "filterByStageArn": NotRequired[str],
        "filterByEncoderConfigurationArn": NotRequired[str],
        "nextToken": NotRequired[str],
        "maxResults": NotRequired[int],
    },
)
ListEncoderConfigurationsRequestRequestTypeDef = TypedDict(
    "ListEncoderConfigurationsRequestRequestTypeDef",
    {
        "nextToken": NotRequired[str],
        "maxResults": NotRequired[int],
    },
)
ListParticipantEventsRequestRequestTypeDef = TypedDict(
    "ListParticipantEventsRequestRequestTypeDef",
    {
        "stageArn": str,
        "sessionId": str,
        "participantId": str,
        "nextToken": NotRequired[str],
        "maxResults": NotRequired[int],
    },
)
ListParticipantsRequestRequestTypeDef = TypedDict(
    "ListParticipantsRequestRequestTypeDef",
    {
        "stageArn": str,
        "sessionId": str,
        "filterByUserId": NotRequired[str],
        "filterByPublished": NotRequired[bool],
        "filterByState": NotRequired[ParticipantStateType],
        "nextToken": NotRequired[str],
        "maxResults": NotRequired[int],
        "filterByRecordingState": NotRequired[ParticipantRecordingFilterByRecordingStateType],
    },
)
ParticipantSummaryTypeDef = TypedDict(
    "ParticipantSummaryTypeDef",
    {
        "participantId": NotRequired[str],
        "userId": NotRequired[str],
        "state": NotRequired[ParticipantStateType],
        "firstJoinTime": NotRequired[datetime],
        "published": NotRequired[bool],
        "recordingState": NotRequired[ParticipantRecordingStateType],
    },
)
ListStageSessionsRequestRequestTypeDef = TypedDict(
    "ListStageSessionsRequestRequestTypeDef",
    {
        "stageArn": str,
        "nextToken": NotRequired[str],
        "maxResults": NotRequired[int],
    },
)
StageSessionSummaryTypeDef = TypedDict(
    "StageSessionSummaryTypeDef",
    {
        "sessionId": NotRequired[str],
        "startTime": NotRequired[datetime],
        "endTime": NotRequired[datetime],
    },
)
ListStagesRequestRequestTypeDef = TypedDict(
    "ListStagesRequestRequestTypeDef",
    {
        "nextToken": NotRequired[str],
        "maxResults": NotRequired[int],
    },
)
StageSummaryTypeDef = TypedDict(
    "StageSummaryTypeDef",
    {
        "arn": str,
        "name": NotRequired[str],
        "activeSessionId": NotRequired[str],
        "tags": NotRequired[Dict[str, str]],
    },
)
ListStorageConfigurationsRequestRequestTypeDef = TypedDict(
    "ListStorageConfigurationsRequestRequestTypeDef",
    {
        "nextToken": NotRequired[str],
        "maxResults": NotRequired[int],
    },
)
ListTagsForResourceRequestRequestTypeDef = TypedDict(
    "ListTagsForResourceRequestRequestTypeDef",
    {
        "resourceArn": str,
    },
)
RecordingConfigurationTypeDef = TypedDict(
    "RecordingConfigurationTypeDef",
    {
        "format": NotRequired[Literal["HLS"]],
    },
)
StopCompositionRequestRequestTypeDef = TypedDict(
    "StopCompositionRequestRequestTypeDef",
    {
        "arn": str,
    },
)
TagResourceRequestRequestTypeDef = TypedDict(
    "TagResourceRequestRequestTypeDef",
    {
        "resourceArn": str,
        "tags": Mapping[str, str],
    },
)
UntagResourceRequestRequestTypeDef = TypedDict(
    "UntagResourceRequestRequestTypeDef",
    {
        "resourceArn": str,
        "tagKeys": Sequence[str],
    },
)
StageTypeDef = TypedDict(
    "StageTypeDef",
    {
        "arn": str,
        "name": NotRequired[str],
        "activeSessionId": NotRequired[str],
        "tags": NotRequired[Dict[str, str]],
        "autoParticipantRecordingConfiguration": NotRequired[
            AutoParticipantRecordingConfigurationOutputTypeDef
        ],
    },
)
AutoParticipantRecordingConfigurationUnionTypeDef = Union[
    AutoParticipantRecordingConfigurationTypeDef, AutoParticipantRecordingConfigurationOutputTypeDef
]
UpdateStageRequestRequestTypeDef = TypedDict(
    "UpdateStageRequestRequestTypeDef",
    {
        "arn": str,
        "name": NotRequired[str],
        "autoParticipantRecordingConfiguration": NotRequired[
            AutoParticipantRecordingConfigurationTypeDef
        ],
    },
)
CompositionSummaryTypeDef = TypedDict(
    "CompositionSummaryTypeDef",
    {
        "arn": str,
        "stageArn": str,
        "destinations": List[DestinationSummaryTypeDef],
        "state": CompositionStateType,
        "tags": NotRequired[Dict[str, str]],
        "startTime": NotRequired[datetime],
        "endTime": NotRequired[datetime],
    },
)
CreateEncoderConfigurationRequestRequestTypeDef = TypedDict(
    "CreateEncoderConfigurationRequestRequestTypeDef",
    {
        "name": NotRequired[str],
        "video": NotRequired[VideoTypeDef],
        "tags": NotRequired[Mapping[str, str]],
    },
)
EncoderConfigurationTypeDef = TypedDict(
    "EncoderConfigurationTypeDef",
    {
        "arn": str,
        "name": NotRequired[str],
        "video": NotRequired[VideoTypeDef],
        "tags": NotRequired[Dict[str, str]],
    },
)
ListTagsForResourceResponseTypeDef = TypedDict(
    "ListTagsForResourceResponseTypeDef",
    {
        "tags": Dict[str, str],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
CreateParticipantTokenResponseTypeDef = TypedDict(
    "CreateParticipantTokenResponseTypeDef",
    {
        "participantToken": ParticipantTokenTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
CreateStageRequestRequestTypeDef = TypedDict(
    "CreateStageRequestRequestTypeDef",
    {
        "name": NotRequired[str],
        "participantTokenConfigurations": NotRequired[
            Sequence[ParticipantTokenConfigurationTypeDef]
        ],
        "tags": NotRequired[Mapping[str, str]],
        "autoParticipantRecordingConfiguration": NotRequired[
            AutoParticipantRecordingConfigurationTypeDef
        ],
    },
)
CreateStorageConfigurationRequestRequestTypeDef = TypedDict(
    "CreateStorageConfigurationRequestRequestTypeDef",
    {
        "s3": S3StorageConfigurationTypeDef,
        "name": NotRequired[str],
        "tags": NotRequired[Mapping[str, str]],
    },
)
StorageConfigurationSummaryTypeDef = TypedDict(
    "StorageConfigurationSummaryTypeDef",
    {
        "arn": str,
        "name": NotRequired[str],
        "s3": NotRequired[S3StorageConfigurationTypeDef],
        "tags": NotRequired[Dict[str, str]],
    },
)
StorageConfigurationTypeDef = TypedDict(
    "StorageConfigurationTypeDef",
    {
        "arn": str,
        "name": NotRequired[str],
        "s3": NotRequired[S3StorageConfigurationTypeDef],
        "tags": NotRequired[Dict[str, str]],
    },
)
DestinationDetailTypeDef = TypedDict(
    "DestinationDetailTypeDef",
    {
        "s3": NotRequired[S3DetailTypeDef],
    },
)
ListEncoderConfigurationsResponseTypeDef = TypedDict(
    "ListEncoderConfigurationsResponseTypeDef",
    {
        "encoderConfigurations": List[EncoderConfigurationSummaryTypeDef],
        "nextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
ListParticipantEventsResponseTypeDef = TypedDict(
    "ListParticipantEventsResponseTypeDef",
    {
        "events": List[EventTypeDef],
        "nextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
GetParticipantResponseTypeDef = TypedDict(
    "GetParticipantResponseTypeDef",
    {
        "participant": ParticipantTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
GetStageSessionResponseTypeDef = TypedDict(
    "GetStageSessionResponseTypeDef",
    {
        "stageSession": StageSessionTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
LayoutConfigurationTypeDef = TypedDict(
    "LayoutConfigurationTypeDef",
    {
        "grid": NotRequired[GridConfigurationTypeDef],
        "pip": NotRequired[PipConfigurationTypeDef],
    },
)
ListParticipantsResponseTypeDef = TypedDict(
    "ListParticipantsResponseTypeDef",
    {
        "participants": List[ParticipantSummaryTypeDef],
        "nextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
ListStageSessionsResponseTypeDef = TypedDict(
    "ListStageSessionsResponseTypeDef",
    {
        "stageSessions": List[StageSessionSummaryTypeDef],
        "nextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
ListStagesResponseTypeDef = TypedDict(
    "ListStagesResponseTypeDef",
    {
        "stages": List[StageSummaryTypeDef],
        "nextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
S3DestinationConfigurationOutputTypeDef = TypedDict(
    "S3DestinationConfigurationOutputTypeDef",
    {
        "storageConfigurationArn": str,
        "encoderConfigurationArns": List[str],
        "recordingConfiguration": NotRequired[RecordingConfigurationTypeDef],
    },
)
S3DestinationConfigurationTypeDef = TypedDict(
    "S3DestinationConfigurationTypeDef",
    {
        "storageConfigurationArn": str,
        "encoderConfigurationArns": Sequence[str],
        "recordingConfiguration": NotRequired[RecordingConfigurationTypeDef],
    },
)
CreateStageResponseTypeDef = TypedDict(
    "CreateStageResponseTypeDef",
    {
        "stage": StageTypeDef,
        "participantTokens": List[ParticipantTokenTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
GetStageResponseTypeDef = TypedDict(
    "GetStageResponseTypeDef",
    {
        "stage": StageTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
UpdateStageResponseTypeDef = TypedDict(
    "UpdateStageResponseTypeDef",
    {
        "stage": StageTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
ListCompositionsResponseTypeDef = TypedDict(
    "ListCompositionsResponseTypeDef",
    {
        "compositions": List[CompositionSummaryTypeDef],
        "nextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
CreateEncoderConfigurationResponseTypeDef = TypedDict(
    "CreateEncoderConfigurationResponseTypeDef",
    {
        "encoderConfiguration": EncoderConfigurationTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
GetEncoderConfigurationResponseTypeDef = TypedDict(
    "GetEncoderConfigurationResponseTypeDef",
    {
        "encoderConfiguration": EncoderConfigurationTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
ListStorageConfigurationsResponseTypeDef = TypedDict(
    "ListStorageConfigurationsResponseTypeDef",
    {
        "storageConfigurations": List[StorageConfigurationSummaryTypeDef],
        "nextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
CreateStorageConfigurationResponseTypeDef = TypedDict(
    "CreateStorageConfigurationResponseTypeDef",
    {
        "storageConfiguration": StorageConfigurationTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
GetStorageConfigurationResponseTypeDef = TypedDict(
    "GetStorageConfigurationResponseTypeDef",
    {
        "storageConfiguration": StorageConfigurationTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
DestinationConfigurationOutputTypeDef = TypedDict(
    "DestinationConfigurationOutputTypeDef",
    {
        "name": NotRequired[str],
        "channel": NotRequired[ChannelDestinationConfigurationTypeDef],
        "s3": NotRequired[S3DestinationConfigurationOutputTypeDef],
    },
)
DestinationConfigurationTypeDef = TypedDict(
    "DestinationConfigurationTypeDef",
    {
        "name": NotRequired[str],
        "channel": NotRequired[ChannelDestinationConfigurationTypeDef],
        "s3": NotRequired[S3DestinationConfigurationTypeDef],
    },
)
DestinationTypeDef = TypedDict(
    "DestinationTypeDef",
    {
        "id": str,
        "state": DestinationStateType,
        "configuration": DestinationConfigurationOutputTypeDef,
        "startTime": NotRequired[datetime],
        "endTime": NotRequired[datetime],
        "detail": NotRequired[DestinationDetailTypeDef],
    },
)
DestinationConfigurationUnionTypeDef = Union[
    DestinationConfigurationTypeDef, DestinationConfigurationOutputTypeDef
]
CompositionTypeDef = TypedDict(
    "CompositionTypeDef",
    {
        "arn": str,
        "stageArn": str,
        "state": CompositionStateType,
        "layout": LayoutConfigurationTypeDef,
        "destinations": List[DestinationTypeDef],
        "tags": NotRequired[Dict[str, str]],
        "startTime": NotRequired[datetime],
        "endTime": NotRequired[datetime],
    },
)
StartCompositionRequestRequestTypeDef = TypedDict(
    "StartCompositionRequestRequestTypeDef",
    {
        "stageArn": str,
        "destinations": Sequence[DestinationConfigurationUnionTypeDef],
        "idempotencyToken": NotRequired[str],
        "layout": NotRequired[LayoutConfigurationTypeDef],
        "tags": NotRequired[Mapping[str, str]],
    },
)
GetCompositionResponseTypeDef = TypedDict(
    "GetCompositionResponseTypeDef",
    {
        "composition": CompositionTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
StartCompositionResponseTypeDef = TypedDict(
    "StartCompositionResponseTypeDef",
    {
        "composition": CompositionTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
